@@ -1,26 +1,9 @@
 """
 UI class for converting raw data from different echosounders to netcdf or zarr.
 """
-from echopype.echodata.echodata import EchoData
-import os
 import warnings
-from datetime import datetime as dt
-from pathlib import Path
-
-import fsspec
-from fsspec.implementations.local import LocalFileSystem
-
-from ..utils import io
-from .parse_azfp import ParseAZFP
-from .parse_ek60 import ParseEK60
-from .parse_ek80 import ParseEK80
-from .parse_ad2cp import ParseAd2cp
-from .set_groups_azfp import SetGroupsAZFP
-from .set_groups_ek60 import SetGroupsEK60
-from .set_groups_ek80 import SetGroupsEK80
-from .set_groups_ad2cp import SetGroupsAd2cp
-from .api import open_raw, MODELS
 
+from .api import open_raw
 
 warnings.simplefilter("always", DeprecationWarning)
 
@@ -40,7 +23,7 @@ CONVERT_PARAMS = [
 # TODO: Used for backwards compatibility. Delete in future versions
 def ConvertEK80(_filename=""):
     warnings.warn(
-        "`ConvertEK80` is deprecated, use echopype.open_raw(raw_file, sonar_model='EK80', ...) instead.",
+        "`ConvertEK80` is deprecated, use echopype.open_raw(raw_file, sonar_model='EK80', ...) instead.",  # noqa
         DeprecationWarning,
         2,
     )
@@ -67,4 +50,3 @@ class Convert:
                 storage_options=storage_options,
             )
         return cls._instance
-
