@@ -653,9 +653,6 @@ class SetGroupsEK80(SetGroupsBase):
 
         return [ds_beam, ds_beam_power]
 
-    def set_beam_complex(self) -> xr.Dataset:
-        return xr.Dataset()
-
     def set_vendor(self) -> xr.Dataset:
         """Set the Vendor-specific group."""
         config = self.parser_obj.config_datagram["configuration"]
