@@ -16,7 +16,7 @@ EK80 broadband echosounder:
   form of average over frequency.
 
 """
-from .process import Process
-from .ek60 import ProcessEK60
-from .azfp import ProcessAZFP
-from .ek80 import ProcessEK80
+from .process_deprecated import Process
+from .process_deprecated import ProcessEK60
+from .process_deprecated import ProcessAZFP
+from .process_deprecated import ProcessEK80
